@@ -1,5 +1,5 @@
 package Beam::Minion::Util;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 # ABSTRACT: Utility functions for Beam::Minion
 
 #pod =head1 SYNOPSIS
@@ -128,14 +128,14 @@ sub build_mojo_app {
             $minion->add_task( "$container_name:$service_name" => sub {
                 my ( $job, @args ) = @_;
 
-                my $obj = eval { $wire->get( $service_name ) };
+                my $obj = eval { $wire->get( $service_name, lifecycle => 'factory' ) };
                 if ( $@ ) {
                     return $job->fail( { error => $@ } );
                 }
 
                 my $exit = eval { $obj->run( @args ) };
-                if ( $@ ) {
-                    return $job->fail( { error => $@ } );
+                if ( my $err = $@ ) {
+                    return $job->fail( { error => $err } );
                 }
 
                 my $method = $exit ? 'fail' : 'finish';
@@ -159,7 +159,7 @@ Beam::Minion::Util - Utility functions for Beam::Minion
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -229,7 +229,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Doug Bell.
+This software is copyright (c) 2018 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
